Test coverage report: myapp2

# myapp2: 5 total statements, 100.0% covered

Generated: Sat 2012-06-09 22:07 SGT

Source file: /Users/martin/Projects/pycon-apac-2012/tdd-with-django/reusable-app/myapp2/__init__.py

Stats: 1 executed, 0 missed, 4 excluded, 1 ignored

1. `# -*- coding: utf-8 -*-`
2. `VERSION = (0, 0, 1, 'alpha')`
3. `if VERSION[-1] != "final": # pragma: no cover`
4. `__version__ = '.'.join(map(str, VERSION))`
5. `else: # pragma: no cover`
6. `__version__ = '.'.join(map(str, VERSION[:-1]))`